******************************
The sherpa.astro.models module
******************************

.. currentmodule:: sherpa.astro.models

.. automodule:: sherpa.astro.models

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Atten
      BBody
      BBodyFreq
      BPL1D
      Beta1D
      Beta2D
      DeVaucouleurs2D
      Dered
      Disk2D
      Edge
      HubbleReynolds
      JDPileup
      LineBroad
      Lorentz1D
      Lorentz2D
      NormBeta1D
      PseudoVoigt1D
      Schechter
      Sersic2D
      Shell2D
      Voigt1D

Class Inheritance Diagram
=========================

.. inheritance-diagram:: Atten BBody BBodyFreq BPL1D Beta1D Beta2D DeVaucouleurs2D Dered Disk2D Edge HubbleReynolds JDPileup LineBroad Lorentz1D Lorentz2D NormBeta1D PseudoVoigt1D Schechter Sersic2D Shell2D Voigt1D
   :parts: 1
